# Torii-HDL Board Definitions

This package contains a collection of board definitions for [Torii], primarily FPGA evaluation boards, but other board files are also planned and welcome to help expand the ecosystem.

## Community

The two primary community spots for Torii and by extension Torii Boards are the `#torii` IRC channel on [libera.chat] (`irc.libera.chat:6697`) which you can join via your favorite IRC client or the [web chat], and the [discussion forum] on GitHub.

Please do join and share your projects using Torii, ask questions, get help with problems, or discuss development.

## License

Torii Boards is released under the [BSD-2-Clause], the full text of which can be found in the [`LICENSE`] file in the root of the [git repository].

The Torii Boards documentation is dual licensed under the [BSD-2-Clause] for all past contributions and the [CC-BY-SA 4.0] for all new and future contributions. The full text of the [CC-BY-SA 4.0] can be found in the [`LICENSE.docs`] file in the root of the [git repository].

[Torii]: https://github.com/shrine-maiden-heavy-industries/torii-hdl
[libera.chat]: https://libera.chat/
[web chat]: https://web.libera.chat/#torii
[discussion forum]: https://github.com/shrine-maiden-heavy-industries/torii-boards/discussions
[BSD-2-Clause]: https://spdx.org/licenses/BSD-2-Clause.html
[`LICENSE`]: https://github.com/shrine-maiden-heavy-industries/torii-boards/blob/main/LICENSE
[CC-BY-SA 4.0]: https://creativecommons.org/licenses/by-sa/4.0/
[`LICENSE.docs`]: https://github.com/shrine-maiden-heavy-industries/torii-boards/blob/main/LICENSE.docs
[git repository]: https://shrine-maiden-heavy.industries/torii-boards
